PieceTable

Struct PieceTable 

pub struct PieceTable<'b> { /* private fields */ }

Implementations

Source

impl<'b> PieceTable<'b>

pub fn new(initial: &'b str) -> Self

Create a new PieceTable with the initial contents set to initial.

Examples
let pt = PieceTable::new("initial");
assert_eq!(pt.text(), "initial");
pub fn text(&self) -> String

Collect the text from the piece table.

This function allocates a new string. You can use PieceTable::iter to iterate over &str chunks without allocations.

Examples
let mut pt = PieceTable::new("content");
pt.insert(0, "abcd, ");
assert_eq!(pt.text(), "abcd, content");
pub fn remove<R>(&mut self, range: R)
where R: RangeBounds<usize>,

Removes the text in the given char index range.

Examples
let mut pt = PieceTable::new("hello_there");
pt.insert(5, "  ");
pt.insert(7, " ");
pt.remove(6..=8);
assert_eq!(pt.text(), "hello there");
let mut pt = PieceTable::new("012345");
pt.remove(0..=5);
assert_eq!(pt.text(), "");
let mut pt = PieceTable::new("012345");
pt.remove(5..0);
assert_eq!(pt.text(), "012345"); // unchanged
pub fn insert(&mut self, char_idx: usize, text: &str)

Insert content at position index.

Examples
let mut pt = PieceTable::new("rld");
pt.insert(0, "hellowo");
pt.insert(5, " ");
assert_eq!(pt.text(), "hello world");
Panics

Will panic if index is larger than the size of the contents.

let mut pt = PieceTable::new("012");
pt.insert(4, " "); // will panic
pub fn len_chars(&self) -> usize

Total number of chars in the piece table.

Runs in O(1).

Examples
let mut pt = PieceTable::new("123456");
assert_eq!(pt.len_chars(), 6);
pub fn len_bytes(&self) -> usize

Total number of bytes in the piece table.

Runs in O(1).

Examples
let mut pt = PieceTable::new("1234⑤");
assert_eq!(pt.len_bytes(), 7); // the 5 takes 3 bytes
pub fn iter(&self) -> impl Iterator<Item = &str>

Returns an iterator over all the &str chunks in the table.

Examples
let mut pt = PieceTable::new("hithere");
pt.insert(2, ", and hello, ");
assert_eq!(pt.iter().collect::<String>(), "hi, and hello, there");